repaint library

Classes

QuadTree
A Quadtree data structure that subdivides a 2D space into four quadrants to speed up collision detection and spatial queries.
QuadTree$Node
A node in the QuadTree that represents a region in the 2D space.
RePaint
A widget that repaints the scene using a custom controller.
RePaintBox
A render object that repaints the scene using a custom controller.
RePaintElement
Element for RePaint.
RePainter
The interface for a custom scene painter.
RePainterBase
The base class for a custom scene painter.
ResourceManager
A resource manager for loading and caching resources.

Extension Types

QuadTree$QueryResult
View over a Float32List that represents a query result.
RePaintFrameRate
The frame rate of the scene.