isEmpty property
bool
get
isEmpty
Whether this tree is empty and has no objects.
Implementation
bool get isEmpty => _length == 0;
Whether this tree is empty and has no objects.
bool get isEmpty => _length == 0;