isNotEmpty property
bool
get
isNotEmpty
Whether this tree is not empty and has objects.
Implementation
bool get isNotEmpty => _length != 0;
Whether this tree is not empty and has objects.
bool get isNotEmpty => _length != 0;