visit method
Visit all nodes in the QuadTree. The walk stops when it iterates over all nodes or when the callback returns false.
Implementation
void visit(bool Function(QuadTree$Node node) visitor) => root?.visit(visitor);
Visit all nodes in the QuadTree. The walk stops when it iterates over all nodes or when the callback returns false.
void visit(bool Function(QuadTree$Node node) visitor) => root?.visit(visitor);