painter property
The painter controller, used to update and paint the scene. For example, a game controller or a custom painter.
Implementation
final RePainter painter;
The painter controller, used to update and paint the scene. For example, a game controller or a custom painter.
final RePainter painter;