RePainter class abstract interface

The interface for a custom scene painter.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
needsPaint bool
The controller needs to be repainted after the update.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

lifecycle(AppLifecycleState state) → void
Lifecycle state change callback. Called when the app lifecycle state changes.
mount(covariant RePaintBox box, PipelineOwner owner) → void
Mount the controller. Called when the controller is attached to the render box.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onPointerEvent(PointerEvent event) → void
Pointer event callback. Called when a pointer event occurs. For example, when the user taps the screen. Events are not propagated to the parent widgets.
paint(covariant RePaintBox box, PaintingContext context) → void
Paint the scene.
toString() String
A string representation of this object.
inherited
unmount() → void
Unmount and dispose the controller. Called when the controller is detached from the render box.
update(covariant RePaintBox box, Duration elapsed, double delta) → void
Loop tick update. Called periodically by the loop.

Operators

operator ==(Object other) bool
The equality operator.
inherited