repaintBoundary property
Whether the controller should create a new layer for the scene.
If true, the controller will create a new layer for the scene.
If false, the controller will not create a new layer for the scene.
This is useful when the controller needs to be repainted frequently separately from the other widgets and the scene is complex and has many layers.
Implementation
final bool repaintBoundary;